pub struct FeatureRegistry {
pub protocol_version: ProtocolVersion,
pub features: Vec<FeatureActivation>,
}Expand description
Feature activation registry for a protocol version
Fields
protocol_version: ProtocolVersionProtocol version
features: Vec<FeatureActivation>Feature activations
Implementations
Sourceimpl FeatureRegistry
impl FeatureRegistry
Sourcepub fn for_protocol(version: ProtocolVersion) -> Self
pub fn for_protocol(version: ProtocolVersion) -> Self
Get feature activations for a protocol version
Sourcepub fn is_feature_active(
&self,
feature_name: &str,
height: u64,
timestamp: u64,
) -> bool
pub fn is_feature_active( &self, feature_name: &str, height: u64, timestamp: u64, ) -> bool
Check if a feature is active at a given height and timestamp
Sourcepub fn get_feature(&self, feature_name: &str) -> Option<&FeatureActivation>
pub fn get_feature(&self, feature_name: &str) -> Option<&FeatureActivation>
Get feature activation information
Sourcepub fn list_features(&self) -> Vec<String>
pub fn list_features(&self) -> Vec<String>
List all features
Sourcepub fn create_context(&self, height: u64, timestamp: u64) -> FeatureContext
pub fn create_context(&self, height: u64, timestamp: u64) -> FeatureContext
Create a FeatureContext for a specific height and timestamp This consolidates all feature activation checks into a single context