pub fn match_filter(filter: &CompactBlockFilter, script: &[u8]) -> boolExpand description
Match a script against a compact block filter
Returns true if the script (or its hash) is likely in the filter
Algorithm:
- Hash the script to get a value in range [0, N*M)
- Decode the filter to reconstruct the sorted set of hashed values
- Check if the script’s hash value is in the set