pub struct FeatureContext {
pub segwit: bool,
pub taproot: bool,
pub csv: bool,
pub cltv: bool,
pub rbf: bool,
pub ctv: bool,
pub height: u64,
pub timestamp: u64,
}Expand description
Feature context consolidating all Bitcoin feature flags at a specific height/timestamp This provides a single source of truth for feature activation state
Fields
segwit: boolSegWit (BIP141/143) activation state
taproot: boolTaproot (BIP341/342) activation state
csv: boolCSV (BIP112) activation state
cltv: boolCLTV (BIP65) activation state
rbf: boolRBF (BIP125) activation state (mempool policy)
ctv: boolCTV (BIP119) activation state
height: u64Block height at which this context is valid
timestamp: u64Timestamp at which this context is valid
Implementations
Sourceimpl FeatureContext
impl FeatureContext
Sourcepub fn from_registry(
registry: &FeatureRegistry,
height: u64,
timestamp: u64,
) -> Self
pub fn from_registry( registry: &FeatureRegistry, height: u64, timestamp: u64, ) -> Self
Create a new feature context from a feature registry
Sourcepub fn active_features(&self) -> Vec<&'static str>
pub fn active_features(&self) -> Vec<&'static str>
Get list of all active features